durationtools.Offset
====================

.. inheritance-diagram:: abjad.tools.durationtools.Offset.Offset.Offset
   :private-bases:

.. autoclass:: abjad.tools.durationtools.Offset.Offset.Offset

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.denominator

    Inherited from :py:class:`fractions.Fraction`

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.imag

    Inherited from :py:class:`numbers.Real`

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.numerator

    Inherited from :py:class:`fractions.Fraction`

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.pair

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.real

    Inherited from :py:class:`numbers.Real`

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.conjugate

    Inherited from :py:class:`numbers.Real`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.from_decimal

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.from_float

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.limit_denominator

    Inherited from :py:class:`fractions.Fraction`

Special Methods
---------------

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__abs__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__add__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__complex__

    Inherited from :py:class:`numbers.Real`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__div__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__divmod__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__eq__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__float__

    Inherited from :py:class:`numbers.Rational`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__floordiv__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__ge__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__gt__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__hash__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__le__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__lt__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__mod__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__mul__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__ne__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__neg__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__nonzero__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__pos__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__pow__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__radd__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rdiv__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rdivmod__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__repr__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rfloordiv__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rmod__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rmul__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rpow__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rsub__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rtruediv__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__str__

    Inherited from :py:class:`fractions.Fraction`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__sub__

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__truediv__

    Inherited from :py:class:`durationtools.Duration <abjad.tools.durationtools.Duration.Duration.Duration>`

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__trunc__

    Inherited from :py:class:`fractions.Fraction`
